==> proshade-0.7.6.0.tar.gz: proshade-0.7.6.0/proshade/documentation/html/_pro_s_h_a_d_e__maths_8hpp.js <==
var _pro_s_h_a_d_e__maths_8hpp =
[
    [ "ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere" ],
    [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
    [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
    [ "binReciprocalSpaceReflections", "_pro_s_h_a_d_e__maths_8hpp.html#aa2702798938d50ec2a55e46cbc31333e", null ],
    [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
    [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
    [ "complexMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#acdc79bf2506934c9ebbda9c13a2722ad", null ],
    [ "complexMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970", null ],
    [ "complexMultiplicationConjug", "_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7", null ],
    [ "complexMultiplicationConjugRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e", null ],
    [ "complexMultiplicationRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6", null ],
    [ "compute3x3MatrixInverse", "_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567", null ],
    [ "compute3x3MatrixMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d", null ],
    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444", null ],
    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a6c83ae1b2f9783ad8df6ff6dfbbc3b9d", null ],
    [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
    [ "computeFSC", "_pro_s_h_a_d_e__maths_8hpp.html#ad3c391ac63c921d19d8d4956d58e0ea8", null ],
    [ "computeGaussian", "_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc", null ],
    [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
    [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
    [ "findRotMatMatchingVectors", "_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b", null ],
    [ "findVectorFromThreeVAndThreeD", "_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603", null ],
    [ "findVectorFromTwoVAndTwoD", "_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7", null ],
    [ "gaussLegendreIntegration", "_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d", null ],
    [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aafc6f1626c7463de53c9f4f6fa11db22", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#a4a379ad8635541b0c7f7f6349822b2a4", null ],
    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df", null ],
    [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
    [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
    [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
    [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
    [ "getResolutionOfReflection", "_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272", null ],
    [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
    [ "multiplyGroupElementMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1", null ],
    [ "multiplyTwoSquareMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151", null ],
    [ "normalDistributionValue", "_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45", null ],
    [ "optimiseAxisBiCubicInterpolation", "_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2", null ],
    [ "pearsonCorrCoeff", "_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff", null ],
    [ "prepareBiCubicInterpolatorsMinusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e", null ],
    [ "prepareBiCubicInterpolatorsMinusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b", null ],
    [ "prepareBiCubicInterpolatorsPlusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147", null ],
    [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
    [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
    [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
    [ "smoothen1D", "_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea", null ],
    [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296", null ],
    [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
    [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
    [ "vectorOrientationSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde", null ],
    [ "vectorOrientationSimilaritySameDirection", "_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0", null ],
    [ "zgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7", null ]
];

==> proshade-0.7.6.2.tar.gz: proshade-0.7.6.2/proshade/documentation/html/_pro_s_h_a_d_e__maths_8hpp.js <==
var _pro_s_h_a_d_e__maths_8hpp =
[
    [ "ProSHADE_rotFun_sphere", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere.html", "class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere" ],
    [ "BicubicInterpolator", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator.html", "class_pro_s_h_a_d_e__internal__maths_1_1_bicubic_interpolator" ],
    [ "advanceGLPolyValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807", null ],
    [ "arrayMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5", null ],
    [ "binReciprocalSpaceReflections", "_pro_s_h_a_d_e__maths_8hpp.html#aa2702798938d50ec2a55e46cbc31333e", null ],
    [ "build3x3MatrixFromDiag", "_pro_s_h_a_d_e__maths_8hpp.html#a5a65abe8c99adbd99419b9c65d25a3b2", null ],
    [ "build3x3MatrixFromXYZRotations", "_pro_s_h_a_d_e__maths_8hpp.html#a12a5f7b87baedbe1cd37ad588d3fca92", null ],
    [ "combineFourierForTranslation", "_pro_s_h_a_d_e__maths_8hpp.html#a64ba4ba55d58078eeea8b70311e4ab49", null ],
    [ "completeLegendreSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad", null ],
    [ "complexMatrixSVDSigmasOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993", null ],
    [ "complexMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970", null ],
    [ "complexMultiplicationConjug", "_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7", null ],
    [ "complexMultiplicationConjugRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e", null ],
    [ "complexMultiplicationRealOnly", "_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6", null ],
    [ "compute3x3MatrixInverse", "_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567", null ],
    [ "compute3x3MatrixMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d", null ],
    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444", null ],
    [ "compute3x3MatrixVectorMultiplication", "_pro_s_h_a_d_e__maths_8hpp.html#a6c83ae1b2f9783ad8df6ff6dfbbc3b9d", null ],
    [ "compute3x3MoorePenrosePseudoInverseOfIMinusMat", "_pro_s_h_a_d_e__maths_8hpp.html#a044f4684d6d52d1242225e3969a4813b", null ],
    [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c", null ],
    [ "computeCrossProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2bbee3728be168eb54099ddb9bc0689a", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea", null ],
    [ "computeDotProduct", "_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601", null ],
    [ "computeFSC", "_pro_s_h_a_d_e__maths_8hpp.html#ab32d795fc4057093f27e5981551f5d99", null ],
    [ "computeFSCWeightByBin", "_pro_s_h_a_d_e__maths_8hpp.html#a4915884de2c0c846d74baf77003ca29c", null ],
    [ "computeGaussian", "_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc", null ],
    [ "computeTheFValue", "_pro_s_h_a_d_e__maths_8hpp.html#a4d8ecf33b4e65b2404ce064b054845b1", null ],
    [ "computeTrFunDerivatives", "_pro_s_h_a_d_e__maths_8hpp.html#a39cf8a79d316806c1140c6cd7a9b49ca", null ],
    [ "computeTrFunStep", "_pro_s_h_a_d_e__maths_8hpp.html#a7fa32a45083a0154c5f0b039bae9ab39", null ],
    [ "dgeev_", "_pro_s_h_a_d_e__maths_8hpp.html#aff2cf3abcfbf8f70b24b369ee3392b12", null ],
    [ "dgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#aa54f5391ab62bf98a331d79d6114c346", null ],
    [ "evaluateGLSeries", "_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675", null ],
    [ "findAllPrimes", "_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495", null ],
    [ "findHighestValueInMap", "_pro_s_h_a_d_e__maths_8hpp.html#a7caf87603d759cb0de1b0bd834ae8f6d", null ],
    [ "findPeaks1D", "_pro_s_h_a_d_e__maths_8hpp.html#ab02121573c2176b879404bad104b33e4", null ],
    [ "findRotMatMatchingVectors", "_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b", null ],
    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#a26fa82e82a6a4af696cfae0581785446", null ],
    [ "findTopGroupSmooth", "_pro_s_h_a_d_e__maths_8hpp.html#a4c9eee80c21be71c62220ea338c0a54b", null ],
    [ "findVectorFromThreeVAndThreeD", "_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603", null ],
    [ "findVectorFromTwoVAndTwoD", "_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7", null ],
    [ "gaussLegendreIntegration", "_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d", null ],
    [ "gaussLegendreIntegrationReal", "_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aad5409074bece14a244fad191524a687", null ],
    [ "getAxisAngleFromRotationMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#aec42a4efcef6dffaf047acde57acea99", null ],
    [ "getEulerZXZFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df", null ],
    [ "getEulerZXZFromRotMatrix", "_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28", null ],
    [ "getEulerZXZFromSOFTPosition", "_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706", null ],
    [ "getGLFirstEvenRoot", "_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2", null ],
    [ "getGLPolyAtZero", "_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432", null ],
    [ "getLegendreAbscAndWeights", "_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065", null ],
    [ "getResolutionOfReflection", "_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49", null ],
    [ "getRotationMatrixFromAngleAxis", "_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1", null ],
    [ "getRotationMatrixFromEulerZXZAngles", "_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272", null ],
    [ "getSOFTPositionFromEulerZXZ", "_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd", null ],
    [ "isAxisUnique", "_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91", null ],
    [ "multiplyGroupElementMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1", null ],
    [ "multiplyTwoSquareMatrices", "_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151", null ],
    [ "normalDistributionValue", "_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45", null ],
    [ "optimiseAxisBiCubicInterpolation", "_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2", null ],
    [ "pearsonCorrCoeff", "_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff", null ],
    [ "prepareBiCubicInterpolatorsMinusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e", null ],
    [ "prepareBiCubicInterpolatorsMinusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b", null ],
    [ "prepareBiCubicInterpolatorsPlusMinus", "_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147", null ],
    [ "prepareBiCubicInterpolatorsPlusPlus", "_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a", null ],
    [ "primeFactorsDecomp", "_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e", null ],
    [ "realMatrixSVDUandVOnly", "_pro_s_h_a_d_e__maths_8hpp.html#a689d9fe55f079cb37a7446103f6103ba", null ],
    [ "rotationMatrixSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e", null ],
    [ "smoothen1D", "_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea", null ],
    [ "transpose3x3MatrixInPlace", "_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296", null ],
    [ "vectorMeanAndSD", "_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8", null ],
    [ "vectorMedianAndIQR", "_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a", null ],
    [ "vectorOrientationSimilarity", "_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde", null ],
    [ "vectorOrientationSimilaritySameDirection", "_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0", null ],
    [ "zgesdd_", "_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7", null ]
];
